Index: Source/core/dom/shadow/ShadowRoot.cpp |
diff --git a/Source/core/dom/shadow/ShadowRoot.cpp b/Source/core/dom/shadow/ShadowRoot.cpp |
index da72c0ceb323c0e48685d1586a5b49d0945360d6..61e9671462c90d63f7a21fda4ba1f83eee318ab5 100644 |
--- a/Source/core/dom/shadow/ShadowRoot.cpp |
+++ b/Source/core/dom/shadow/ShadowRoot.cpp |
@@ -87,11 +87,11 @@ ShadowRoot::~ShadowRoot() |
documentInternal()->styleEngine()->didRemoveShadowRoot(this); |
// We cannot let ContainerNode destructor call willBeDeletedFrom() |
// for this ShadowRoot instance because TreeScope destructor |
// clears Node::m_treeScope thus ContainerNode is no longer able |
// to access it Document reference after that. |
- willBeDeletedFrom(documentInternal()); |
+ willBeDeletedFromDocument(); |
// We must remove all of our children first before the TreeScope destructor |
// runs so we don't go through TreeScopeAdopter for each child with a |
@@ -87,11 +87,11 @@ ShadowRoot::~ShadowRoot() |
documentInternal()->styleEngine()->didRemoveShadowRoot(this); |
- // We cannot let ContainerNode destructor call willBeDeletedFrom() |
+ // We cannot let ContainerNode destructor call willBeDeletedFromDocument() |
// for this ShadowRoot instance because TreeScope destructor |
// clears Node::m_treeScope thus ContainerNode is no longer able |